SystemOrganization addCategory: #NumberPrinterTests!

TestCase subclass: #FloatPrinterTest
	instanceVariableNames: 'printer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'NumberPrinterTests'!

!FloatPrinterTest methodsFor: 'private' stamp: ''!
assertThatNumber: aNumber printsAs: aString
	self assert: (printer print: aNumber) equals: aString! !

!FloatPrinterTest methodsFor: 'private' stamp: 'nice 3/5/2018 23:31'!
assertThatParsing: sourceString printsAs: aString
	"We cannot trust the Smalltalk compiler: it does not answer nearest Float"
	^self assertThatNumber: (ExtendedNumberParser parse: sourceString) printsAs: aString! !

!FloatPrinterTest methodsFor: 'initialize-release' stamp: ''!
setUp
	printer := FloatPrinter new.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:26'!
testFixedFormat
	printer := FloatPrinter fixed.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatNumber: 1000000.0 printsAs: '1000000'.
	self assertThatNumber: 1000.0 printsAs: '1000'.
	self assertThatNumber: 10.0 printsAs: '10'.
	self assertThatNumber: -1.0 printsAs: '-1'.
	self assertThatNumber: 0.1 printsAs: '0.1'.
	self assertThatNumber: 0.0001 printsAs: '0.0001'.
	self assertThatNumber: 0.000001 printsAs: '0.000001'.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '0.'.
	self assertThatNumber: -300.0 printsAs: '-300.'.
	self assertThatNumber: 4.0 printsAs: '4.'.
	self assertThatNumber: 0.06 printsAs: '0.06'.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '0.0'.
	self assertThatNumber: 70.0 printsAs: '70.0'.
	self assertThatNumber: 8.0 printsAs: '8.0'.
	self assertThatNumber: 0.9 printsAs: '0.9'.
	printer positiveSignChar: $+.
	self assertThatNumber: 0.0 printsAs: '+0.0'.
	self assertThatNumber: -300.1 printsAs: '-300.1'.
	self assertThatNumber: 0.0579 printsAs: '+0.0579'.
	printer positiveSignChar: $ .
	self assertThatNumber: 2.3 printsAs: ' 2.3'.
	printer fractionSeparator: $,.
	self assertThatNumber: 0.0 printsAs: ' 0,0'.
	self assertThatNumber: -5.8 printsAs: '-5,8'.
	self assertThatNumber: 0.042 printsAs: ' 0,042'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:26'!
testFixedFormatFixedWidth
	printer := FloatPrinter fixed.
	printer totalWidth: 10.
	self assert: (printer print: 1.234) size equals: 10.
	self assertThatNumber: 1.234 printsAs: '     1.234'.
	self assertThatNumber: -1.234 printsAs: '    -1.234'.
	printer padWithZeros: true.
	self assertThatNumber: 1.234 printsAs: '000001.234'.
	self assertThatNumber: -1.234 printsAs: '-00001.234'.
	printer positiveSignChar: $ .
	self assertThatNumber: 1.234 printsAs: ' 00001.234'.
	printer digitCount: 2.
	self assertThatNumber: 1.234 printsAs: ' 000001.23'.
	printer padWithZeros: false.
	printer positiveSignChar: $+.
	self assertThatNumber: 1.234 printsAs: '     +1.23'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScaling
	printer := FloatPrinter fixed.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatParsing: '-0.0' printsAs: '-0'.
	self assertThatParsing: '9.4951e6' printsAs: '9495100'.
	self assertThatParsing: '9.4951e5' printsAs: '949510'.
	self assertThatParsing: '9.4951e4' printsAs: '94951'.
	self assertThatParsing: '9.4951e3' printsAs: '9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '94.951'.
	self assertThatParsing: '9.4951e0' printsAs: '9.4951'.
	self assertThatParsing: '9.4951e-1' printsAs: '0.94951'.
	self assertThatParsing: '9.4951e-2' printsAs: '0.094951'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.0094951'.
	self assertThatParsing: '9.4951e-4' printsAs: '0.00094951'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingDigitCount
	printer := FloatPrinter fixed.
	printer digitCount: 2.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatParsing: '-0.0' printsAs: '-0'.
	self assertThatParsing: '9.4951e6' printsAs: '9495100'.
	self assertThatParsing: '9.4951d5' printsAs: '949510'.
	self assertThatParsing: '9.4951e4' printsAs: '94951'.
	self assertThatParsing: '9.4951e3' printsAs: '9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '94.95'.
	self assertThatParsing: '9.4951e0' printsAs: '9.5'.
	self assertThatParsing: '9.4951e-1' printsAs: '0.95'.
	self assertThatParsing: '9.4951e-2' printsAs: '0.09'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.01'.
	self assertThatParsing: '9.4951e-4' printsAs: '0'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingDigitCountFractionPart
	printer := FloatPrinter fixed.
	printer digitCount: 2.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '0.0'.
	self assertThatParsing: '-0.0' printsAs: '-0.0'.
	self assertThatParsing: '9.4951e6' printsAs: '9495100.0'.
	self assertThatParsing: '9.4951d5' printsAs: '949510.0'.
	self assertThatParsing: '9.4951e4' printsAs: '94951.0'.
	self assertThatParsing: '9.4951e3' printsAs: '9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '94.95'.
	self assertThatParsing: '9.4951e0' printsAs: '9.5'.
	self assertThatParsing: '9.4951e-1' printsAs: '0.95'.
	self assertThatParsing: '9.4951e-2' printsAs: '0.09'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.01'.
	self assertThatParsing: '9.4951e-4' printsAs: '0.0'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingDigitCountTrailingZeros
	printer := FloatPrinter fixed.
	printer digitCount: 2.
	printer showTrailingZeros: true.
	self assertThatNumber: 0.0 printsAs: '0.00'.
	self assertThatParsing: '-0.0' printsAs: '-0.00'.
	self assertThatParsing: '9.4951e6' printsAs: '9495100.00'.
	self assertThatParsing: '9.4951d5' printsAs: '949510.00'.
	self assertThatParsing: '9.4951e4' printsAs: '94951.00'.
	self assertThatParsing: '9.4951e3' printsAs: '9495.10'.
	self assertThatParsing: '9.4951e2' printsAs: '949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '94.95'.
	self assertThatParsing: '9.4951e0' printsAs: '9.50'.
	self assertThatParsing: '9.4951e-1' printsAs: '0.95'.
	self assertThatParsing: '9.4951e-2' printsAs: '0.09'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.01'.
	self assertThatParsing: '9.4951e-4' printsAs: '0.00'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimited
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	self assertThatNumber: 0.0 printsAs: '        0'.
	self assertThatParsing: '-0.0' printsAs: '       -0'.
	self assertThatParsing: '9.4951e6' printsAs: '  9495100'.
	self assertThatParsing: '9.4951e5' printsAs: '   949510'.
	self assertThatParsing: '9.4951e4' printsAs: '    94951'.
	self assertThatParsing: '9.4951e3' printsAs: '   9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '   949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '   94.951'.
	self assertThatParsing: '9.4951e0' printsAs: '   9.4951'.
	self assertThatParsing: '9.4951e-1' printsAs: '  0.94951'.
	self assertThatParsing: '9.4951e-2' printsAs: ' 0.094951'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.0094951'.
	self assertThatParsing: '9.4951e-4' printsAs: '0.00094951'. "Note: more than 9 characters are printed"! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimitedDigitCount
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	printer digitCount: 2.
	self assertThatNumber: 0.0 printsAs: '        0'.
	self assertThatParsing: '-0.0' printsAs: '       -0'.
	self assertThatParsing: '9.4951e6' printsAs: '  9495100'.
	self assertThatParsing: '9.4951e5' printsAs: '   949510'.
	self assertThatParsing: '9.4951e4' printsAs: '    94951'.
	self assertThatParsing: '9.4951e3' printsAs: '   9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '   949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '    94.95'.
	self assertThatParsing: '9.4951e0' printsAs: '      9.5'.
	self assertThatParsing: '9.4951e-1' printsAs: '     0.95'.
	self assertThatParsing: '9.4951e-2' printsAs: '     0.09'.
	self assertThatParsing: '9.4951e-3' printsAs: '     0.01'.
	self assertThatParsing: '9.4951e-4' printsAs: '        0'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimitedDigitCountFractionPart
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	printer digitCount: 2.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '      0.0'.
	self assertThatParsing: '-0.0' printsAs: '     -0.0'.
	self assertThatParsing: '9.4951e6' printsAs: '9495100.0'.
	self assertThatParsing: '9.4951e5' printsAs: ' 949510.0'.
	self assertThatParsing: '9.4951e4' printsAs: '  94951.0'.
	self assertThatParsing: '9.4951e3' printsAs: '   9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '   949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '    94.95'.
	self assertThatParsing: '9.4951e0' printsAs: '      9.5'.
	self assertThatParsing: '9.4951e-1' printsAs: '     0.95'.
	self assertThatParsing: '9.4951e-2' printsAs: '     0.09'.
	self assertThatParsing: '9.4951e-3' printsAs: '     0.01'.
	self assertThatParsing: '9.4951e-4' printsAs: '      0.0'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimitedDigitCountTrailingZeros
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	printer digitCount: 2.
	printer showTrailingZeros: true.
	self assertThatNumber: 0.0 printsAs: '     0.00'.
	self assertThatParsing: '-0.0' printsAs: '    -0.00'.
	self assertThatParsing: '9.4951e6' printsAs: '9495100.00'.	"Note: more than 9 characters are printed"
	self assertThatParsing: '9.4951e5' printsAs: '949510.00'.
	self assertThatParsing: '9.4951e4' printsAs: ' 94951.00'.
	self assertThatParsing: '9.4951e3' printsAs: '  9495.10'.
	self assertThatParsing: '9.4951e2' printsAs: '   949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '    94.95'.
	self assertThatParsing: '9.4951e0' printsAs: '     9.50'.
	self assertThatParsing: '9.4951e-1' printsAs: '     0.95'.
	self assertThatParsing: '9.4951e-2' printsAs: '     0.09'.
	self assertThatParsing: '9.4951e-3' printsAs: '     0.01'.
	self assertThatParsing: '9.4951e-4' printsAs: '     0.00'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimitedFractionSeparator
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '       0.'.
	self assertThatParsing: '-0.0' printsAs: '      -0.'.
	self assertThatParsing: '9.4951e6' printsAs: ' 9495100.'.
	self assertThatParsing: '9.4951e5' printsAs: '  949510.'.
	self assertThatParsing: '9.4951e4' printsAs: '   94951.'.
	self assertThatParsing: '9.4951e3' printsAs: '   9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '   949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '   94.951'.
	self assertThatParsing: '9.4951e0' printsAs: '   9.4951'.
	self assertThatParsing: '9.4951e-1' printsAs: '  0.94951'.
	self assertThatParsing: '9.4951e-2' printsAs: ' 0.094951'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.0094951'.
	self assertThatParsing: '9.4951e-4' printsAs: '0.00094951'. "Note: more than 9 characters are printed"! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimitedPadded
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	printer padWithZeros: true.
	self assertThatNumber: 0.0 printsAs: '000000000'.
	self assertThatParsing: '-0.0' printsAs: '-00000000'.
	self assertThatParsing: '9.4951e6' printsAs: '009495100'.
	self assertThatParsing: '9.4951e5' printsAs: '000949510'.
	self assertThatParsing: '9.4951e4' printsAs: '000094951'.
	self assertThatParsing: '9.4951e3' printsAs: '0009495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '000949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '00094.951'.
	self assertThatParsing: '9.4951e0' printsAs: '0009.4951'.
	self assertThatParsing: '9.4951e-1' printsAs: '000.94951'.
	self assertThatParsing: '9.4951e-2' printsAs: '00.094951'.
	self assertThatParsing: '9.4951e-3' printsAs: '0.0094951'.
	self assertThatParsing: '9.4951e-4' printsAs: '0.00094951'. "Note: more than 9 characters are printed"! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFixedFormatScalingLimitedSign
	printer := FloatPrinter fixed.
	printer totalWidth: 9.
	printer forceSign: true.
	self assertThatNumber: 0.0 printsAs: '       +0'.
	self assertThatParsing: '-0.0' printsAs: '       -0'.
	self assertThatParsing: '9.4951e6' printsAs: ' +9495100'.
	self assertThatParsing: '9.4951e5' printsAs: '  +949510'.
	self assertThatParsing: '9.4951e4' printsAs: '   +94951'.
	self assertThatParsing: '9.4951e3' printsAs: '  +9495.1'.
	self assertThatParsing: '9.4951e2' printsAs: '  +949.51'.
	self assertThatParsing: '9.4951e1' printsAs: '  +94.951'.
	self assertThatParsing: '9.4951e0' printsAs: '  +9.4951'.
	self assertThatParsing: '9.4951e-1' printsAs: ' +0.94951'.
	self assertThatParsing: '9.4951e-2' printsAs: '+0.094951'.
	self assertThatParsing: '9.4951e-3' printsAs: '+0.0094951'. "Note: more than 9 characters are printed"
	self assertThatParsing: '9.4951e-4' printsAs: '+0.00094951'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:25'!
testFixedFormatWithDigitCount
	printer := FloatPrinter fixed.
	printer digitCount: 0.
	self assertThatNumber: Float pi printsAs: '3'.
	printer digitCount: 1.
	self assertThatNumber: Float pi printsAs: '3.1'.
	printer digitCount: 2.
	self assertThatNumber: Float pi printsAs: '3.14'.
	self assertThatNumber: 9.99499 printsAs: '9.99'.
	self assertThatNumber: 9.9499 printsAs: '9.95'.
	self assertThatNumber: 0.99499 printsAs: '0.99'.
	self assertThatNumber: 0.099499 printsAs: '0.1'.
	self assertThatNumber: 0.099501 printsAs: '0.1'.
	self assertThatNumber: 0.99501 printsAs: '1'.
	self assertThatNumber: 9.9501 printsAs: '9.95'.
	self assertThatNumber: 9.99501 printsAs: '10'.
	printer digitCount: 3.
	self assertThatNumber: Float pi printsAs: '3.142'.
	self assertThatNumber: 0.099499 printsAs: '0.099'.
	self assertThatNumber: 0.099501 printsAs: '0.1'.
	printer digitCount: 4.
	self assertThatNumber: Float pi printsAs: '3.1416'.
	self assertThatNumber: 0.1200499 printsAs: '0.12'.
	self assertThatNumber: 0.1200501 printsAs: '0.1201'.
	
	printer := FloatPrinter fixed.
	printer showTrailingZeros: true.
	printer digitCount: 2.
	self assertThatNumber: 0.99501 printsAs: '1.00'.
	self assertThatNumber: 0.101 printsAs: '0.10'.
! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormat
	printer := FloatPrinter freeFormat.
	self assertThatNumber: 0.0 printsAs: '0'.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '0.'.
	self assertThatNumber: 20000000.0 printsAs: '2.e7'.
	self assertThatNumber: 300.0 printsAs: '300.'.
	self assertThatNumber: 40.0 printsAs: '40.'.
	self assertThatNumber: 5.0 printsAs: '5.'.
	self assertThatNumber: -0.6 printsAs: '-0.6'.
	self assertThatNumber: 0.07 printsAs: '0.07'.
	self assertThatNumber: 0.000008 printsAs: '8.e-6'.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '0.0'.
	self assertThatNumber: 10000000.0 printsAs: '1.0e7'.
	self assertThatNumber: 100.0 printsAs: '100.0'.
	self assertThatNumber: -10.0 printsAs: '-10.0'.
	self assertThatNumber: 1.0 printsAs: '1.0'.
	self assertThatNumber: 0.1 printsAs: '0.1'.
	self assertThatNumber: 0.01 printsAs: '0.01'.
	self assertThatNumber: 0.000001 printsAs: '1.0e-6'.
	printer positiveSignChar: $+.
	self assertThatNumber: 0.0 printsAs: '+0.0'.
	self assertThatNumber: 10200000.0 printsAs: '+1.02e+7'.
	self assertThatNumber: 100.03 printsAs: '+100.03'.
	self assertThatNumber: 0.014 printsAs: '+0.014'.
	self assertThatNumber: -0.00000105 printsAs: '-1.05e-6'.
	printer positiveSignChar: $ .
	self assertThatNumber: 10030000.0 printsAs: ' 1.003e+7'.
	printer exponentChar: $d.
	self assertThatNumber: 10030000.0 printsAs: ' 1.003d+7'.
	printer exponentDigitCount: 2.
	self assertThatNumber: 10030000.0 printsAs: ' 1.003d+07'.
	self assertThatNumber: -0.00000105 printsAs: '-1.05d-06'.
	printer fractionSeparator: $,.
	self assertThatNumber: 0.0 printsAs: ' 0,0'.
	self assertThatNumber: -0.00000105 printsAs: '-1,05d-06'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatDefaultExpRange
	"Use fixed point when base exponent is between -4 and 6, scientific otherwise"
	printer := FloatPrinter freeFormat.
	self assertThatNumber: 10000000.0 printsAs: '1e7'.
	self assertThatNumber: 1000000.0 printsAs: '1e6'.
	self assertThatNumber: 100000.0 printsAs: '100000'.
	self assertThatNumber: 10000.0 printsAs: '10000'.
	self assertThatNumber: 1000.0 printsAs: '1000'.
	self assertThatNumber: 100.0 printsAs: '100'.
	self assertThatNumber: 10.0 printsAs: '10'.
	self assertThatNumber: -1.0 printsAs: '-1'.
	self assertThatNumber: 0.1 printsAs: '0.1'.
	self assertThatNumber: 0.01 printsAs: '0.01'.
	self assertThatNumber: 0.001 printsAs: '0.001'.
	self assertThatNumber: 0.0001 printsAs: '0.0001'.
	self assertThatNumber: 0.00001 printsAs: '1e-5'.
	self assertThatNumber: 0.000001 printsAs: '1e-6'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:24'!
testFreeFormatFixedWidth
	printer := FloatPrinter freeFormat.
	printer totalWidth: 7.
	self assert: (printer print: 100.0) size equals: 7.
	self assertThatNumber: 100.0 printsAs: '    100'.
	self assertThatNumber: 1000.0 printsAs: '    1e3'. "Shortest notation is used"
	self assertThatNumber: -1001.0 printsAs: '  -1001'. "Shortest notation is used"
	printer digitCount: 2.
	self assertThatNumber: -10012.0 printsAs: '   -1e4'. "Shortest notation is used"
	printer showTrailingZeros: true.
	self assertThatNumber: -10012.0 printsAs: ' -10000'. "Shortest notation is used"! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScaling
	printer := FloatPrinter freeFormat.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatParsing: '-0.0' printsAs: '-0'.
	self assertThatParsing: '9.4941e7' printsAs: '9.4941e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.4951e6'.
	self assertThatParsing: '9.4961e5' printsAs: '949610'.
	self assertThatParsing: '9.4971e4' printsAs: '94971'.
	self assertThatParsing: '9.4981e3' printsAs: '9498.1'.
	self assertThatParsing: '9.4991e2' printsAs: '949.91'.
	self assertThatParsing: '9.5001e1' printsAs: '95.001'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5011'.
	self assertThatParsing: '9.5021e-1' printsAs: '0.95021'.
	self assertThatParsing: '9.5031e-2' printsAs: '0.095031'.
	self assertThatParsing: '9.5041e-3' printsAs: '0.0095041'.
	self assertThatParsing: '9.5051e-4' printsAs: '0.00095051'.
	self assertThatParsing: '9.5061e-5' printsAs: '9.5061e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingDigitCount
	printer := FloatPrinter freeFormat.
	printer digitCount: 3.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatParsing: '-0.0' printsAs: '-0'.
	self assertThatParsing: '9.4941e7' printsAs: '9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.5e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.5e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.5e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.5e3'.
	self assertThatParsing: '9.4991e2' printsAs: '950'.
	self assertThatParsing: '9.5001e1' printsAs: '95'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.51e-4'.
	self assertThatParsing: '9.5061e-5' printsAs: '9.51e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingDigitCountFractionPart
	printer := FloatPrinter freeFormat.
	printer digitCount: 3.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '0.0'.
	self assertThatParsing: '-0.0' printsAs: '-0.0'.
	self assertThatParsing: '9.4941e7' printsAs: '9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.5e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.5e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.5e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.5e3'.
	self assertThatParsing: '9.4991e2' printsAs: '950.0'.
	self assertThatParsing: '9.5001e1' printsAs: '95.0'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.51e-4'.
	self assertThatParsing: '9.5061e-5' printsAs: '9.51e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingDigitCountFractionSeparator
	printer := FloatPrinter freeFormat.
	printer digitCount: 3.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '0.'.
	self assertThatParsing: '-0.0' printsAs: '-0.'.
	self assertThatParsing: '9.4941e7' printsAs: '9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.5e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.5e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.5e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.5e3'.
	self assertThatParsing: '9.4991e2' printsAs: '950.'.
	self assertThatParsing: '9.5001e1' printsAs: '95.'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.51e-4'.
	self assertThatParsing: '9.5061e-5' printsAs: '9.51e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingDigitCountTrailingZeros
	printer := FloatPrinter freeFormat.
	printer digitCount: 3.
	printer showTrailingZeros: true.
	self assertThatNumber: 0.0 printsAs: '0.00'.
	self assertThatParsing: '-0.0' printsAs: '-0.00'.
	self assertThatParsing: '9.4941e7' printsAs: '9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.50e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.50e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.50e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.50e3'.
	self assertThatParsing: '9.4991e2' printsAs: '950'.
	self assertThatParsing: '9.5001e1' printsAs: '95.0'.
	self assertThatParsing: '9.5011e0' printsAs: '9.50'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.50e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.50e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.50e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.51e-4'.
	self assertThatParsing: '9.5061e-5' printsAs: '9.51e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingLimited
	printer := FloatPrinter freeFormat.
	printer totalWidth: 9.
	self assertThatNumber: 0.0 printsAs: '        0'.
	self assertThatParsing: '-0.0' printsAs: '       -0'.
	self assertThatParsing: '9.4941e7' printsAs: ' 94941000'.
	self assertThatParsing: '9.4951e6' printsAs: '  9495100'.
	self assertThatParsing: '9.4961e5' printsAs: '   949610'.
	self assertThatParsing: '9.4971e4' printsAs: '    94971'.
	self assertThatParsing: '9.4981e3' printsAs: '   9498.1'.
	self assertThatParsing: '9.4991e2' printsAs: '   949.91'.
	self assertThatParsing: '9.5001e1' printsAs: '   95.001'.
	self assertThatParsing: '9.5011e0' printsAs: '   9.5011'.
	self assertThatParsing: '9.5021e-1' printsAs: '  0.95021'.
	self assertThatParsing: '9.5031e-2' printsAs: ' 0.095031'.
	self assertThatParsing: '9.5041e-3' printsAs: '0.0095041'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.5051e-4'.
	self assertThatParsing: '9.5061e-5' printsAs: '9.5061e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingLimitedDigitCount
	printer := FloatPrinter freeFormat.
	printer totalWidth: 9.
	printer digitCount: 3.
	self assertThatNumber: 0.0 printsAs: '        0'.
	self assertThatParsing: '-0.0' printsAs: '       -0'.
	self assertThatParsing: '9.4941e7' printsAs: '   9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '    9.5e6'.
	self assertThatParsing: '9.4961e5' printsAs: '    9.5e5'.
	self assertThatParsing: '9.4971e4' printsAs: '    95000'.
	self assertThatParsing: '9.4981e3' printsAs: '     9500'.
	self assertThatParsing: '9.4991e2' printsAs: '      950'.
	self assertThatParsing: '9.5001e1' printsAs: '       95'.
	self assertThatParsing: '9.5011e0' printsAs: '      9.5'.
	self assertThatParsing: '9.5021e-1' printsAs: '     0.95'.
	self assertThatParsing: '9.5031e-2' printsAs: '    0.095'.
	self assertThatParsing: '9.5041e-3' printsAs: '   0.0095'.
	self assertThatParsing: '9.5051e-4' printsAs: '  9.51e-4'.
	self assertThatParsing: '9.5061e-5' printsAs: '  9.51e-5'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testFreeFormatScalingLimitedDigitCountExponentDigits
	printer := FloatPrinter freeFormat.
	printer totalWidth: 9.
	printer digitCount: 3.
	printer exponentDigitCount: 2.
	self assertThatNumber: 0.0 printsAs: '        0'.
	self assertThatParsing: '-0.0' printsAs: '       -0'.
	self assertThatParsing: '9.4941e7' printsAs: '  9.49e07'.
	self assertThatParsing: '9.4951e6' printsAs: '   9.5e06'.
	self assertThatParsing: '9.4961e5' printsAs: '   950000'.
	self assertThatParsing: '9.4971e4' printsAs: '    95000'.
	self assertThatParsing: '9.4981e3' printsAs: '     9500'.
	self assertThatParsing: '9.4991e2' printsAs: '      950'.
	self assertThatParsing: '9.5001e1' printsAs: '       95'.
	self assertThatParsing: '9.5011e0' printsAs: '      9.5'.
	self assertThatParsing: '9.5021e-1' printsAs: '     0.95'.
	self assertThatParsing: '9.5031e-2' printsAs: '    0.095'.
	self assertThatParsing: '9.5041e-3' printsAs: '   0.0095'.
	self assertThatParsing: '9.5051e-4' printsAs: ' 0.000951'.
	self assertThatParsing: '9.5061e-5' printsAs: ' 9.51e-05'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:23'!
testFreeFormatWithDigitCount
	printer := FloatPrinter freeFormat.
	printer digitCount: 1.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatNumber: 100.0 printsAs: '1e2'.
	self assertThatNumber: 10.0 printsAs: '1e1'.
	self assertThatNumber: -1.0 printsAs: '-1'.
	self assertThatNumber: 0.1 printsAs: '1e-1'.
	self assertThatNumber: 9.49 printsAs: '9'.
	self assertThatNumber: 0.949 printsAs: '9e-1'.
	self assertThatNumber: 0.951 printsAs: '1'.
	self assertThatNumber: 9.51 printsAs: '1e1'.
	self assertThatNumber: 0.0951 printsAs: '1e-1'.
	
	printer digitCount: 2.
	self assertThatNumber: 100.0 printsAs: '1e2'.
	self assertThatNumber: 10.0 printsAs: '10'.
	self assertThatNumber: -1.0 printsAs: '-1'.
	self assertThatNumber: 0.1 printsAs: '1e-1'.
	self assertThatNumber: 9.949 printsAs: '9.9'.
	self assertThatNumber: 0.9949 printsAs: '9.9e-1'.
	self assertThatNumber: 0.9951 printsAs: '1'.
	self assertThatNumber: 9.951 printsAs: '10'.

	printer showTrailingZeros: true.
	self assertThatNumber: 100.0 printsAs: '1.0e2'.
	self assertThatNumber: 10.0 printsAs: '10'.
	self assertThatNumber: -1.0 printsAs: '-1.0'.
	self assertThatNumber: 0.1 printsAs: '1.0e-1'.
	self assertThatNumber: 99.49 printsAs: '99'.
	self assertThatNumber: 9.949 printsAs: '9.9'.
	self assertThatNumber: 0.9949 printsAs: '9.9e-1'.
	self assertThatNumber: 0.9951 printsAs: '1.0'.
	self assertThatNumber: 9.951 printsAs: '10'.
	self assertThatNumber: 99.51 printsAs: '1.0e2'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:23'!
testScientificFormat
	printer := FloatPrinter scientific.
	self assertThatNumber: 0.0 printsAs: '0e0'.
	self assertThatNumber: 1000.0 printsAs: '1e3'.
	self assertThatNumber: 100.0 printsAs: '1e2'.
	self assertThatNumber: 10.0 printsAs: '1e1'.
	self assertThatNumber: -1.0 printsAs: '-1e0'.
	self assertThatNumber: 0.1 printsAs: '1e-1'.
	self assertThatNumber: 0.01 printsAs: '1e-2'.
	self assertThatNumber: 0.001 printsAs: '1e-3'.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '0.e0'.
	self assertThatNumber: -300.0 printsAs: '-3.e2'.
	self assertThatNumber: 4.0 printsAs: '4.e0'.
	self assertThatNumber: 0.06 printsAs: '6.e-2'.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '0.0e0'.
	self assertThatNumber: 70.0 printsAs: '7.0e1'.
	self assertThatNumber: -0.8 printsAs: '-8.0e-1'.
	printer positiveSignChar: $+.
	self assertThatNumber: 0.0 printsAs: '+0.0e+0'.
	self assertThatNumber: -300.1 printsAs: '-3.001e+2'.
	self assertThatNumber: 0.0579 printsAs: '+5.79e-2'.
	printer positiveSignChar: $ .
	self assertThatNumber: 2.3 printsAs: ' 2.3e+0'.
	printer exponentChar: $d.
	self assertThatNumber: 2.3 printsAs: ' 2.3d+0'.
	printer exponentDigitCount: 2.
	self assertThatNumber: -310.0 printsAs: '-3.1d+02'.
	self assertThatNumber: 4.0 printsAs: ' 4.0d+00'.
	self assertThatNumber: 0.06 printsAs: ' 6.0d-02'.
	self assertThatNumber: 1.0e100 printsAs: ' 1.0d+100'.
	printer fractionSeparator: $,.
	self assertThatNumber: 0.0 printsAs: ' 0,0d+00'.
	self assertThatNumber: -5.8 printsAs: '-5,8d+00'.
	self assertThatNumber: 0.042 printsAs: ' 4,2d-02'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:45'!
testScientificFormatFixedWidth
	printer := FloatPrinter scientific.
	printer totalWidth: 8.
	self assertThatNumber: 0.1 printsAs: '    1e-1'.
	self assertThatNumber: -10.1 printsAs: ' -1.01e1'.
	printer padWithZeros: true.
	self assertThatNumber: -10.1 printsAs: '-01.01e1'.
	self assertThatNumber: 3.14 printsAs: '003.14e0'.
	printer positiveSignChar: $+.
	printer totalWidth: 10.
	self assertThatNumber: 3.14 printsAs: '+003.14e+0'.
	self assert: (Number readFromString: (printer print: Float pi)) equals: Float pi.
	printer digitCount: 2.
	printer padWithZeros: false.
	self assertThatNumber: Float pi printsAs: '  +3.14e+0'.
	! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScaling
	printer := FloatPrinter scientific.
	self assertThatNumber: 0.0 printsAs: '0e0'.
	self assertThatParsing: '-0.0' printsAs: '-0e0'.
	self assertThatParsing: '9.4941e7' printsAs: '9.4941e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.4951e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.4961e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.4971e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.4981e3'.
	self assertThatParsing: '9.4991e2' printsAs: '9.4991e2'.
	self assertThatParsing: '9.5001e1' printsAs: '9.5001e1'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5011e0'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5021e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5031e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5041e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.5051e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingDigitCount
	printer := FloatPrinter scientific.
	printer digitCount: 2.
	self assertThatNumber: 0.0 printsAs: '0e0'.
	self assertThatParsing: '-0.0' printsAs: '-0e0'.
	self assertThatParsing: '9.4941e7' printsAs: '9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.5e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.5e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.5e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.5e3'.
	self assertThatParsing: '9.4991e2' printsAs: '9.5e2'.
	self assertThatParsing: '9.5001e1' printsAs: '9.5e1'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5e0'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.51e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingDigitCountRoundedUp
	printer := FloatPrinter scientific.
	printer digitCount: 1.
	self assertThatParsing: '9.951e6' printsAs: '1e7'.
	self assertThatParsing: '9.951e5' printsAs: '1e6'.
	self assertThatParsing: '9.951e4' printsAs: '1e5'.
	self assertThatParsing: '9.951e3' printsAs: '1e4'.
	self assertThatParsing: '9.951e2' printsAs: '1e3'.
	self assertThatParsing: '9.951e1' printsAs: '1e2'.
	self assertThatParsing: '9.951e0' printsAs: '1e1'.
	self assertThatParsing: '9.951e-1' printsAs: '1e0'.
	self assertThatParsing: '9.951e-2' printsAs: '1e-1'.
	self assertThatParsing: '9.951e-3' printsAs: '1e-2'.
	self assertThatParsing: '9.951e-4' printsAs: '1e-3'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingDigitCountTrailingZeros
	printer := FloatPrinter scientific.
	printer digitCount: 2.
	printer showTrailingZeros: true.
	self assertThatNumber: 0.0 printsAs: '0.00e0'.
	self assertThatParsing: '-0.0' printsAs: '-0.00e0'.
	self assertThatParsing: '9.4941e7' printsAs: '9.49e7'.
	self assertThatParsing: '9.4951e6' printsAs: '9.50e6'.
	self assertThatParsing: '9.4961e5' printsAs: '9.50e5'.
	self assertThatParsing: '9.4971e4' printsAs: '9.50e4'.
	self assertThatParsing: '9.4981e3' printsAs: '9.50e3'.
	self assertThatParsing: '9.4991e2' printsAs: '9.50e2'.
	self assertThatParsing: '9.5001e1' printsAs: '9.50e1'.
	self assertThatParsing: '9.5011e0' printsAs: '9.50e0'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.50e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.50e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.50e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.51e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingLimited
	printer := FloatPrinter scientific.
	printer totalWidth: 9.
	self assertThatNumber: 0.0 printsAs: '      0e0'.
	self assertThatParsing: '-0.0' printsAs: '     -0e0'.
	self assertThatParsing: '9.4941e7' printsAs: ' 9.4941e7'.
	self assertThatParsing: '9.4951e6' printsAs: ' 9.4951e6'.
	self assertThatParsing: '9.4961e5' printsAs: ' 9.4961e5'.
	self assertThatParsing: '9.4971e4' printsAs: ' 9.4971e4'.
	self assertThatParsing: '9.4981e3' printsAs: ' 9.4981e3'.
	self assertThatParsing: '9.4991e2' printsAs: ' 9.4991e2'.
	self assertThatParsing: '9.5001e1' printsAs: ' 9.5001e1'.
	self assertThatParsing: '9.5011e0' printsAs: ' 9.5011e0'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5021e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5031e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5041e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.5051e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingLimitedExponentDigit
	printer := FloatPrinter scientific.
	printer totalWidth: 9.
	printer exponentDigitCount: 2.
	self assertThatNumber: 0.0 printsAs: '     0e00'.
	self assertThatParsing: '-0.0' printsAs: '    -0e00'.
	self assertThatParsing: '9.4941e7' printsAs: '9.4941e07'.
	self assertThatParsing: '9.4951e6' printsAs: '9.4951e06'.
	self assertThatParsing: '9.4961e5' printsAs: '9.4961e05'.
	self assertThatParsing: '9.4971e4' printsAs: '9.4971e04'.
	self assertThatParsing: '9.4981e3' printsAs: '9.4981e03'.
	self assertThatParsing: '9.4991e2' printsAs: '9.4991e02'.
	self assertThatParsing: '9.5001e1' printsAs: '9.5001e01'.
	self assertThatParsing: '9.5011e0' printsAs: '9.5011e00'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5021e-01'.	"Note that more than 9 characters are printed"
	self assertThatParsing: '9.5031e-2' printsAs: '9.5031e-02'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5041e-03'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.5051e-04'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingLimitedForceSign
	printer := FloatPrinter scientific.
	printer totalWidth: 9.
	printer forceSign: true.
	self assertThatNumber: 0.0 printsAs: '    +0e+0'.
	self assertThatParsing: '-0.0' printsAs: '    -0e+0'.
	self assertThatParsing: '9.4941e7' printsAs: '+9.4941e+7'.	"Note that more than 9 characters are printed"
	self assertThatParsing: '9.4951e6' printsAs: '+9.4951e+6'.
	self assertThatParsing: '9.4961e5' printsAs: '+9.4961e+5'.
	self assertThatParsing: '9.4971e4' printsAs: '+9.4971e+4'.
	self assertThatParsing: '9.4981e3' printsAs: '+9.4981e+3'.
	self assertThatParsing: '9.4991e2' printsAs: '+9.4991e+2'.
	self assertThatParsing: '9.5001e1' printsAs: '+9.5001e+1'.
	self assertThatParsing: '9.5011e0' printsAs: '+9.5011e+0'.
	self assertThatParsing: '9.5021e-1' printsAs: '+9.5021e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '+9.5031e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '+9.5041e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '+9.5051e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingLimitedFractionPart
	printer := FloatPrinter scientific.
	printer totalWidth: 9.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '    0.0e0'.
	self assertThatParsing: '-0.0' printsAs: '   -0.0e0'.
	self assertThatParsing: '9.4941e7' printsAs: ' 9.4941e7'.
	self assertThatParsing: '9.4951e6' printsAs: ' 9.4951e6'.
	self assertThatParsing: '9.4961e5' printsAs: ' 9.4961e5'.
	self assertThatParsing: '9.4971e4' printsAs: ' 9.4971e4'.
	self assertThatParsing: '9.4981e3' printsAs: ' 9.4981e3'.
	self assertThatParsing: '9.4991e2' printsAs: ' 9.4991e2'.
	self assertThatParsing: '9.5001e1' printsAs: ' 9.5001e1'.
	self assertThatParsing: '9.5011e0' printsAs: ' 9.5011e0'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5021e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5031e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5041e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.5051e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: ''!
testScientificFormatScalingLimitedFractionSeparator
	printer := FloatPrinter scientific.
	printer totalWidth: 9.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '     0.e0'.
	self assertThatParsing: '-0.0' printsAs: '    -0.e0'.
	self assertThatParsing: '9.4941e7' printsAs: ' 9.4941e7'.
	self assertThatParsing: '9.4951e6' printsAs: ' 9.4951e6'.
	self assertThatParsing: '9.4961e5' printsAs: ' 9.4961e5'.
	self assertThatParsing: '9.4971e4' printsAs: ' 9.4971e4'.
	self assertThatParsing: '9.4981e3' printsAs: ' 9.4981e3'.
	self assertThatParsing: '9.4991e2' printsAs: ' 9.4991e2'.
	self assertThatParsing: '9.5001e1' printsAs: ' 9.5001e1'.
	self assertThatParsing: '9.5011e0' printsAs: ' 9.5011e0'.
	self assertThatParsing: '9.5021e-1' printsAs: '9.5021e-1'.
	self assertThatParsing: '9.5031e-2' printsAs: '9.5031e-2'.
	self assertThatParsing: '9.5041e-3' printsAs: '9.5041e-3'.
	self assertThatParsing: '9.5051e-4' printsAs: '9.5051e-4'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:21'!
testScientificFormatWithDigitCount
	printer := FloatPrinter scientific.
	printer digitCount: 0.
	self assertThatNumber: 0.0 printsAs: '0e0'.
	self assertThatNumber: 1000.0 printsAs: '1e3'.
	self assertThatNumber: 1200.0 printsAs: '1e3'.
	self assertThatNumber: 0.01 printsAs: '1e-2'.
	self assertThatNumber: 1.7 printsAs: '2e0'.
	self assertThatNumber: 0.17 printsAs: '2e-1'.
	self assertThatNumber: 0.017 printsAs: '2e-2'.
	self assertThatNumber: 9.9 printsAs: '1e1'.
	self assertThatNumber: 0.99 printsAs: '1e0'.
	printer digitCount: 1.
	self assertThatNumber: 1.7 printsAs: '1.7e0'.
	self assertThatNumber: 0.17 printsAs: '1.7e-1'.
	self assertThatNumber: 0.017 printsAs: '1.7e-2'.
	self assertThatNumber: 100.0 printsAs: '1e2'.
	self assertThatNumber: 130.0 printsAs: '1.3e2'.
	self assertThatNumber: 9.99 printsAs: '1e1'.
	self assertThatNumber: 0.99499 printsAs: '9.9e-1'.
	self assertThatNumber: 0.996 printsAs: '1e0'.
	
	printer showTrailingZeros: true.
	printer digitCount: 2.
	self assertThatNumber: 9.99499 printsAs: '9.99e0'.
	self assertThatNumber: 0.999499 printsAs: '9.99e-1'.
	self assertThatNumber: 0.0999499 printsAs: '9.99e-2'.
	self assertThatNumber: 0.0999501 printsAs: '1.00e-1'.
	self assertThatNumber: 0.999501 printsAs: '1.00e0'.
	self assertThatNumber: 9.99501 printsAs: '1.00e1'.
	self assertThatNumber: -314.159 printsAs: '-3.14e2'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:21'!
testThousandFormat
	printer := FloatPrinter thousand.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatNumber: 10.0 printsAs: '10'.
	self assertThatNumber: 100.0 printsAs: '100'.
	self assertThatNumber: 1000.0 printsAs: '1e3'.
	self assertThatNumber: 10000.0 printsAs: '10e3'.
	self assertThatNumber: -1.0 printsAs: '-1'.
	self assertThatNumber: 0.1 printsAs: '100e-3'.
	self assertThatNumber: 0.01 printsAs: '10e-3'.
	self assertThatNumber: 0.001 printsAs: '1e-3'.
	printer alwaysPrintFractionSeparator: true.
	self assertThatNumber: 0.0 printsAs: '0.'.
	self assertThatNumber: -3000.0 printsAs: '-3.e3'.
	self assertThatNumber: 4.0 printsAs: '4.'.
	self assertThatNumber: 0.06 printsAs: '60.e-3'.
	printer alwaysPrintFractionPart: true.
	self assertThatNumber: 0.0 printsAs: '0.0'.
	self assertThatNumber: 70.0 printsAs: '70.0'.
	self assertThatNumber: -0.8 printsAs: '-800.0e-3'.
	printer positiveSignChar: $+.
	self assertThatNumber: 0.0 printsAs: '+0.0'.
	self assertThatNumber: -3000.1 printsAs: '-3.0001e+3'.
	self assertThatNumber: 0.0579 printsAs: '+57.9e-3'.
	printer positiveSignChar: $ .
	self assertThatNumber: 2.3 printsAs: ' 2.3'.
	printer exponentChar: $d.
	self assertThatNumber: 2300 printsAs: ' 2.3d+3'.
	printer exponentDigitCount: 2.
	self assertThatNumber: -3100.0 printsAs: '-3.1d+03'.
	self assertThatNumber: 4.0 printsAs: ' 4.0'.
	self assertThatNumber: 0.06 printsAs: ' 60.0d-03'.
	self assertThatNumber: 1.0e110 printsAs: ' 100.0d+108'.
	printer fractionSeparator: $,.
	self assertThatNumber: 0.0 printsAs: ' 0,0'.
	self assertThatNumber: -5.8 printsAs: '-5,8'.
	self assertThatNumber: 0.0042 printsAs: ' 4,2d-03'.! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:46'!
testThousandFormatFixedWidth
	printer := FloatPrinter thousand.
	printer totalWidth: 8.
	self assertThatNumber: 0.1 printsAs: '  100e-3'.
	self assertThatNumber: -10.1 printsAs: '   -10.1'.
	printer padWithZeros: true.
	self assertThatNumber: -10.1 printsAs: '  -010.1'.
	self assertThatNumber: 3.14 printsAs: '  003.14'.
	printer positiveSignChar: $+.
	printer totalWidth: 10.
	self assertThatNumber: 3.14 printsAs: '   +003.14'.
	self assert: (Number readFromString: (printer print: Float pi)) equals: Float pi.
	printer digitCount: -2.
	printer padWithZeros: false.
	self assertThatNumber: Float pi printsAs: '     +3.14'.
	! !

!FloatPrinterTest methodsFor: 'testing' stamp: 'nice 3/5/2018 23:19'!
testThousandFormatWithDigitCount
	printer := FloatPrinter thousand.
	printer digitCount: 1.
	self assertThatNumber: 0.0 printsAs: '0'.
	self assertThatNumber: 10000.0 printsAs: '10e3'.
	self assertThatNumber: 1200.0 printsAs: '1e3'.
	self assertThatNumber: 0.01 printsAs: '10e-3'.
	self assertThatNumber: 1.7 printsAs: '2'.
	self assertThatNumber: 0.17 printsAs: '200e-3'.
	self assertThatNumber: 0.017 printsAs: '20e-3'.
	self assertThatNumber: 9.9 printsAs: '10'.
	self assertThatNumber: 0.99 printsAs: '1'.
	printer digitCount: 5.
	self assertThatNumber: 100.099 printsAs: '100.1'.
	self assertThatNumber: 12345.67 printsAs: '12.346e3'.
	self assertThatNumber: 0.00999499 printsAs: '9.995e-3'.
	self assertThatNumber: 0.09999499 printsAs: '99.995e-3'.
	self assertThatNumber: 0.99999499 printsAs: '999.99e-3'.
	self assertThatNumber: 0.99999501 printsAs: '1'.
	printer digitCount: -1.
	self assertThatNumber: 1.7 printsAs: '1.7'.
	self assertThatNumber: 0.17 printsAs: '170e-3'.
	self assertThatNumber: 0.017 printsAs: '17e-3'.
	self assertThatNumber: 100.0 printsAs: '100'.
	self assertThatNumber: 130.0 printsAs: '130'.
	self assertThatNumber: 9.99 printsAs: '10'.
	self assertThatNumber: 0.999499 printsAs: '999.5e-3'.
	self assertThatNumber: 0.9996 printsAs: '999.6e-3'.
	
	printer showTrailingZeros: true.
	printer digitCount: -2.
	self assertThatNumber: 9.99499 printsAs: '9.99'.
	self assertThatNumber: 0.999499 printsAs: '999.50e-3'.
	self assertThatNumber: 0.0999499 printsAs: '99.95e-3'.
	self assertThatNumber: 0.00999499 printsAs: '9.99e-3'.
	self assertThatNumber: 0.00999501 printsAs: '10.00e-3'.
	self assertThatNumber: 0.0999501 printsAs: '99.95e-3'.
	self assertThatNumber: 0.999501 printsAs: '999.50e-3'.
	self assertThatNumber: 9.99501 printsAs: '10.00'.
	self assertThatNumber: -314.159 printsAs: '-314.16'.! !
